Enumeration
GlySandboxSelector
since: 2.0
Description [src]
Sandbox mechanisms
Warning
Using GLY_SANDBOX_SELECTOR_NOT_SANDBOXED will disable an important security layer that sandboxes loaders. It is only intended for testing and development purposes.
Available since: 2.0
Members
-
GLY_SANDBOX_SELECTOR_AUTO -
This mode selects
bwrapoutside of Flatpaks and usuallyflatpak-spawninside of Flatpaks. The sandbox is disabled automatically inside of Flatpak development environments. Inside of Flatpaks,flatpak-spawnis used to create the sandbox. This mechanism starts an installed Flatpak with the same app id. For development, Flatpak are usually not installed and the sandbox can therefore not be used. If the sandbox has been started viaflatpak-builder --run(i.e. without installed Flatpak) and the app id ends withDevel, the sandbox is disabled.- Value:
0 - Available since: 2.0
- Value:
-
GLY_SANDBOX_SELECTOR_BWRAP -
Bwrap.
- Value:
1 - Available since: 2.0
- Value:
-
GLY_SANDBOX_SELECTOR_FLATPAK_SPAWN -
Flatpak-spawn.
- Value:
2 - Available since: 2.0
- Value:
-
GLY_SANDBOX_SELECTOR_NOT_SANDBOXED -
Disable sandbox. Unsafe, only use for testing and development.
- Value:
3 - Available since: 2.0
- Value: